@@ -1,4 +1,5 @@
-/* GObject introspection: Parsed GIR
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
+ * GObject introspection: Parsed GIR
  *
  * Copyright (C) 2005 Matthias Clasen
  *
@@ -206,6 +207,7 @@ struct _GIrNodeVFunc
   gboolean must_be_implemented;
   gboolean must_not_be_implemented;
   gboolean is_class_closure;
+  gboolean throws;
 
   char *invoker;
 
