@@ -1,4 +1,5 @@
-/* GObject introspection: A parser for the XML GIR format
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
+ * GObject introspection: A parser for the XML GIR format
  *
  * Copyright (C) 2005 Matthias Clasen
  * Copyright (C) 2008 Philip Van Hoof
@@ -2345,6 +2346,7 @@ start_vfunc (GMarkupParseContext *context,
   const gchar *is_class_closure;
   const gchar *offset;
   const gchar *invoker;
+  const gchar *throws;
   GIrNodeInterface *iface;
   GIrNodeVFunc *vfunc;
 
@@ -2362,6 +2364,7 @@ start_vfunc (GMarkupParseContext *context,
   is_class_closure = find_attribute ("is-class-closure", attribute_names, attribute_values);
   offset = find_attribute ("offset", attribute_names, attribute_values);
   invoker = find_attribute ("invoker", attribute_names, attribute_values);
+  throws = find_attribute ("throws", attribute_names, attribute_values);
 
   if (name == NULL)
     {
@@ -2400,6 +2403,11 @@ start_vfunc (GMarkupParseContext *context,
   else
     vfunc->is_class_closure = FALSE;
 
+  if (throws && strcmp (throws, "1") == 0)
+    vfunc->throws = TRUE;
+  else
+    vfunc->throws = FALSE;
+
   if (offset)
     vfunc->offset = atoi (offset);
   else
@@ -3503,10 +3511,11 @@ _g_ir_parser_parse_string (GIrParser           *parser,
   if (ctx.modules)
     return ctx.modules->data;
 
-  g_set_error (error,
-               G_MARKUP_ERROR,
-               G_MARKUP_ERROR_INVALID_CONTENT,
-               "Expected namespace element in the gir file");
+  if (error && *error == NULL)
+    g_set_error (error,
+                 G_MARKUP_ERROR,
+                 G_MARKUP_ERROR_INVALID_CONTENT,
+                 "Expected namespace element in the gir file");
   return NULL;
 }
 
